#! /bin/bash
# Last edited on 2010-05-05 21:25:20 by stolfilocal

# Usage:
#   $0  -size {SIZE} -reference {REFTAG} -methods {METHOD}.. -datasets ${DATASET}..
# If a ${METHOD} is "=" it is turned into an hline.

methods=()
nmt=0
datasets=()
nds=0
cur="???"
size="XXX"
reftag="XXX"
while [[ $# -gt 0 ]] ; do 
  if [[ "/$1" == "/-methods" ]]; then
    cur="m"; shift
  elif [[ "/$1" == "/-datasets" ]]; then
    cur="d"; shift
  elif [[ ( $# -ge 2 ) && ( "/$1" == "/-size" ) ]]; then
    size="$2"; shift; shift
  elif [[ ( $# -ge 2 ) && ( "/$1" == "/-reference" ) ]]; then
    reftag="$2"; shift; shift
  elif [[ "/$1" =~ "^/-" ]]; then
    echo "** unknown option \"$1\"" 1>&2; exit 1
  else
    if [[ "/${cur}" == "/m" ]]; then 
      methods[$nmt]="$1"; nmt=$(( ${nmt} + 1 )); shift
    elif [[ "/${cur}" == "/d" ]]; then 
      datasets[$nds]="$1"; nds=$(( ${nds} + 1 )); shift
    else
      echo "** missing \"-methods\" or \"-datasets\"" 1>&2; exit 1
    fi
  fi
done

# Metrics to print for each dataset and method:
metrics=( 'e' 're' )
metricnames=( '$e$' '$e/R$' )
nme=2

printf '%% Created by $0 -- DO NOT EDIT BY HAND, edits will be lost\n' 

# Print table preamble
printf '\\def\\tbh#1#2{\\mcol{#1}{c||}{\\texttt{#2}}}\n' 
printf '\\begin{tabular}{|l|' 
ids=0;
while [[ ${ids} -lt ${nds} ]]; do 
  printf '|'
  ime=0
  while [[ ${ime} -lt ${nme} ]]; do 
    printf 'r|'
    ime=$(( ${ime} + 1 ))
  done
  ids=$(( ${ids} + 1 ))
done
printf '}\n'

printf '  \\hline\n' 

# Print header 1
printf '  %-8s' '~'
ids=0;
while [[ ${ids} -lt ${nds} ]]; do 
  dsname="${datasets[$ids]}"
  hdr=`printf '\\\\tbh{%d}{%s}' "${nme}" "${dsname}"`
  printf ' & %21s' "${hdr}"
  ids=$(( ${ids} + 1 ))
done
printf ' \\\\\n'

printf '  \\hline\n' 

# Print header 2
printf '  %-8s' 'Meth.'
ids=0;
while [[ ${ids} -lt ${nds} ]]; do 
  ime=0
  while [[ ${ime} -lt ${nme} ]]; do 
    mena="${metricnames[${ime}]}"
    printf ' & %9s' "${mena}"    
    # echo "mena = ${mena}" 1>&2;
    ime=$(( ${ime} + 1 ))
  done
  ids=$(( ${ids} + 1 ))
done
printf ' \\\\\n'

printf '  \\hline\n' 

# Print data
      
imt=0
while [[ ${imt} -lt ${nmt} ]]; do  
  mt="${methods[${imt}]}"
  if [[ "/${mt}" == "/=" ]]; then
    printf '  \\hline\n' 
  else
    mtname=${mt%.*}
    mttag=${mt#*.}
    printf '  %-8s' "${mttag}"
    ids=0;
    while [[ ${ids} -lt ${nds} ]]; do 
      dsname="${datasets[${ids}]}"
      # echo "mtname = ${mtname}  mttag = ${mttag}  dsname = ${dsname}" 1>&2;
      datafile="data/${dsname}-${mtname}-${size}-${reftag}.txt"
      if [[ -s ${datafile} ]]; then
        data=( `cat ${datafile}` )
        e="${data[0]}"
        re="${data[1]}"
        R="${data[2]}"
      else
        echo '** missing file "'"${datafile}"'"' 1>&2;
        e="???"
        re="???"
        R="???"
      fi
      # echo "mtname = ${mtname}  mttag = ${mttag}  dsname = ${dsname}  R = ${R}  e = ${e}  re = ${re}" 1>&2;
      ime=0
      while [[ ${ime} -lt ${nme} ]]; do 
        metric="${metrics[${ime}]}"
        if [[ "/${e}" == "/???" ]]; then
          val="???"
          fmt="%9s"
        elif [[ "/${metric}" == "/R" ]]; then
          val="${R}"
          fmt='%9.1f'
        elif [[ "/${metric}" == "/e" ]]; then
          val="${e}"
          fmt='%9.2f'
        elif [[ "/${metric}" == "/re" ]]; then
          val=`echo "${re}*100.0" | bc -lq`
          fmt='%5.1f{\\%%}'
        else
          echo '** unknown metric "'"${metric}"'"' 1>&2; exit 1
        fi
        val=`printf "${fmt}" "${val}"`
        echo "mtname = ${mtname}  mttag = ${mttag}  dsname = ${dsname}  metric = ${metric}  R = ${R}  e = ${e}  re = ${re}  val = ${val}" 1>&2;
        printf ' & %9s' "${val}"
        ime=$(( ${ime} + 1 ))
      done
      ids=$(( ${ids} + 1 ))
    done
    printf ' \\\\\n'
  fi
  imt=$(( ${imt} + 1 ))
done

printf '  \\hline\n'

# Print table postamble
printf '\\end{tabular}\n'
