#! /bin/bash
# Last edited on 2010-05-06 17:06:18 by stolfilocal

dataset="$1"; shift
methods=( "$@" )

tmp="/tmp/$$"
gplfile="${tmp}.gpl"
epsfile="${tmp}.eps"

# Point types (should be enough):
voidpts=( 4 6 8 12 ) 
fullpts=( 5 7 9 13 ) 

# Gather datapoints and collect one datapoint for each method:
maxsizes=()
maxtimes=()
powers=()
linetypes=()
pointtypes=()
nvoid=0
nfull=0
for mt in ${methods[@]} ; do 
  mname=${mt%.*}
  mtag=${mt#*.}
  if [[ "/${mname}" =~ "/mscl" ]]; then
    pwr="1.0"; ltp="1"; ptp="${fullpts[${nfull}]}"; nfull=$(( ${nfull} + 1 ))
  else
    pwr="1.5"; ltp="3"; ptp="${voidpts[${nvoid}]}"; nvoid=$(( ${nvoid} + 1 ))
  fi
  datafile="${tmp}-${mname}.dat"
  cat data/${dataset}-${mname}-*-CST.txt \
    | sort -k1,1n \
    > ${datafile}
  last=( `tail -1 ${datafile}` )
  mxsz="${last[0]}";
  mxtm="${last[1]}"
  echo "mname = ${mname}  mtag = ${mtag}  pwr = ${pwr}  ltp = ${ltp}  ptp=${ptp}  mxsz = ${mxsz}  mxtm = ${mxtm}" 1>&2;
  maxsizes=( "${maxsizes[@]}" "${mxsz}" )
  maxtimes=( "${maxtimes[@]}" "${mxtm}" )
  powers=( "${powers[@]}" "${pwr}" )
  linetypes=( "${linetypes[@]}" "${ltp}" )
  pointtypes=( "${pointtypes[@]}" "${ptp}" )
done

# Create plotfile
cat > ${gplfile} <<EOF
  set term postscript eps monochrome "TimesRoman" 24 \
    dashlength 2.0 linewidth 2.0 \
    size 4.0,3.0 
  set pointsize 1.5
  set output "${epsfile}" 
  set xrange [(64*64/2):(512*512*2)]
  set logscale x
  set yrange [0.01/1.015:1000.0*1.05]
  set title "${dataset} (sec)" offset 0,-2.25
  set key left reverse Left samplen 1.5
  set xtics ( \
    "32x32" (32*32), \
    "64x64" (64*64), \
    "128x128" (128*128), \
    "256x256" (256*256), \
    "512x512" (512*512) \
  )
  set logscale y
EOF

imth=0
sep=""
printf 'plot' >> ${gplfile}
for mt in ${methods[@]} ; do 
  mname=${mt%.*}
  mtag=${mt#*.}
  echo "mname = ${mname}  mtag = ${mtag}" 1>&2;
  datafile="${tmp}-${mname}.dat"
  mxsz="${maxsizes[${imth}]}"
  mxtm="${maxtimes[${imth}]}"
  pwr="${powers[${imth}]}"
  ltp="${linetypes[${imth}]}"
  ptp="${pointtypes[${imth}]}"
  printf "${sep}"' \\\n' >> ${gplfile}
  printf '  '"${mxtm}"'*((x+0.0)/'"${mxsz}"')**'"${pwr}"' notitle with lines' >> ${gplfile}
  printf ' lt '"${ltp}"', \\\n' >> ${gplfile}
  printf '  "'"${datafile}"'" using 1:2 title "'"${mtag}"'" with points pt '"${ptp}" >> ${gplfile}
  imth=$(( ${imth} + 1 ))
  sep=","
done
  
printf '\n' >> ${gplfile}
printf 'quit\n' >> ${gplfile}

gnuplot < ${gplfile}

# ( gv ${epsfile}; echo "ta-da." 1>&2; )

cat ${epsfile}

rm -f ${tmp}.* ${tmp}-*.*
